pitchtools.numbered_inversion_equivalent_interval_class_dictionary
==================================================================

.. autofunction:: abjad.tools.pitchtools.numbered_inversion_equivalent_interval_class_dictionary.numbered_inversion_equivalent_interval_class_dictionary
